#
# spec file for package jtdx
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define rel_tag 159

Name:           jtdx
Version:        2.2.%{rel_tag}
Release:        1.26
Summary:        Weak signal hamradio software
License:        GPL-3.0-only
Group:          Productivity/Hamradio/Other
URL:            https://github.com/jtdx-project/jtdx
#GitClone:      https://github.com/jtdx-project/jtdx.git
Source:         https://github.com/jtdx-project/jtdx/archive/refs/tags/%{rel_tag}.tar.gz#/%{name}-%{rel_tag}.tar.gz
BuildRequires:  asciidoc
BuildRequires:  cmake
BuildRequires:  fftw3-threads-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hamlib >= 4.0
BuildRequires:  hamlib-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libqt5-qtmultimedia-devel
BuildRequires:  libqt5-qtserialport-devel
BuildRequires:  libqt5-qtwebsockets-devel
BuildRequires:  libQt5Concurrent-devel
BuildRequires:  libQt5PrintSupport-devel
BuildRequires:  systemd-devel
Requires(post): update-desktop-files
Requires(postun):update-desktop-files

%description
JTDX is forked from WSJT-X, a computer program dedicated to amateur
radio communication using very weak signals.

%prep
%setup -q -n %{name}-%{rel_tag}

%build
%cmake \
     -DWSJT_GENERATE_DOCS=OFF 
%cmake_build

%install
%cmake_install

# move installed docs to _docdir (Leap 15.5 and older)
%if 0%{?suse_version} == 1500 && 0%{?sle_version} <= 150500
mkdir -p %{buildroot}/%{_docdir}/%{name}
mv %{buildroot}/%{_datadir}/doc/JTDX/* %{buildroot}/%{_docdir}/%{name}
%endif

# remove installed but not needed files
rm %{buildroot}/%{_docdir}/%{name}/COPYING
rm %{buildroot}/%{_docdir}/%{name}/INSTALL
rm %{buildroot}/%{_docdir}/%{name}/copyright
rm %{buildroot}/%{_docdir}/%{name}/changelog.Debian.gz

# rename some man files
mv %{buildroot}/%{_mandir}/man1/udp_daemon.1%{ext_man} %{buildroot}/%{_mandir}/man1/udp_daemon_jtdx.1%{ext_man}
mv %{buildroot}/%{_mandir}/man1/wsprd.1%{ext_man} %{buildroot}/%{_mandir}/man1/wsprd_jtdx.1%{ext_man}

%suse_update_desktop_file %{name} Network HamRadio


%files
%license COPYING
%doc AUTHORS BUGS NEWS README THANKS 
%{_bindir}/*jtdx*
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}_icon.png
%{_datadir}/%{name}
%{_mandir}/man1/*.1%{ext_man}
%exclude %{_mandir}/man1/jt65code.1%{ext_man}
%exclude %{_mandir}/man1/message_aggregator.1%{ext_man}

%changelog
* Sat Jun 22 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- new spec file
- new URL and source file location (Github)
- updated to version (tag) 2.2.159
  * TCI ESDR2 known issues: starting JTDX with ESDR2 have problems
    in configuration where Split is enabled in ESDR2 and Split Rig
    option disabled in JTDX, this issue can be fixed in ESDR2
    software only
  * TCI: fix test ptt with TCI audio
  * TCI: try to decode first incomplete interval after JTDX
    launching or band change
  * TCI: better way to handle delay, restore split when changed id
    esdr to off
  * TCI: patch to JTDX configurations Split None and Split Fake It
  * TCI: code reworked to cope with ESDR band memory
  * TCI: changes to support Thetis HPSDR CAT over TCI
  * TCI: restore ESDR mode to started mode on closing JTDX, set
    correct drive value on starting JTDX
  * FT8 decoder: better CQ signal recognition in QRM environment
  * FT8 decoder: reduced Lag, reduced average Lag at QSO
  * FT8 decoder: bug fixed, CQ mask shall be used in nonstd mycall
    configuration
  * FT8 decoder: enable averaging of CQ signals with standard
    callsign in nonstandard DXCall configuration
  * FT8 decoder: improved sensitivity for decoding CQ signals
  * FT8 decoder: improved sensitivity for decoding answers to
    operator's CQ in standard mycall configuration
  * FT8 decoder: multiple changes in AP mask usage
  * FT8 decoder: multiple changes in filtering false decodes
  * FT8 decoder: fix bug in filtering iaptype1 false CQ decodes
  * FT8 decoder: use median filter in average DT calculation,
    reworked average DT calculation
  * FT8 decoder: update prefix to grid mapping, fixed bug in prefix
    to grid mapping for Libya
  * FT8 decoder: start decoder earlier to reduce Lag values
    Early start -0.5 .. 0.68 sec DT range with no signal loss
    Regular start -0.5 .. 0.97 sec DT range with no signal loss
    SWL(late start) -0.5 .. 1.54 sec DT range with no signal loss
  * FT8 decoder: fix audio .wav files decoding in SWL and early
    start modes
  * FT8 decoder: fast track for average DT calculation after Sync or
    mode change
  * AutoSeq: added looking back for incoming calls with mycall for 5
    minutes for autoselect
  * AutoSeq: simplified counters implementation
  * AutoSeq: fix retransmitting counter problem
  * Fox/Hound: relax FT8 common band guard interval requirements for
    Hound TX frequency control from -3 .. 3 KHz rounded values range
    to -2 .. 3 KHz one
  * Text filters: improve 'hide messages within own continent' filter
  * UDP Reply: move raising up task bar under window popup option
  * respond to duplicated 'UDP Reply' message with duplicated 'Status
    Update' message, also duplicated 'Status Update' message will be
    sent out if received 'UDP Reply' message with callsign already
    located in DX Call window
  * add WSJT-X code: wrap QProcess to avoid inherited handles
    causing issues on Windows
  * JTDX Rig Split mode: fixed setting VFO B frequency if VFO A
    frequency is changed in transceiver
  * set correct power values on start of JTDX
  * patch to country name/prefix displaying for free text messages
  * fix ARRL RTTY contest message parsing
  * fix decodedtext label height
  * Hamlib PTT port sharing is moved to option in Settings/Radio
  * updated INSTALL instructions
  * changed default values to have more comfortable first launch
    of JTDX
  * display 1.00 SWR, SWR displaying format is changed to x.xx
  * improved country name recognition with cty.dat
  * JTDX Web site link updated
  * add TX AF frequency recording in ALL.TXT
  * ALLCALL7.TXT update as of 20220228, big cty as of 20220222,
    LoTW list update as of 20220221
  * new functionality: user can trigger synchronization to signals
    in RX audio stream with Sync button in main window UI, tooltip
    added, translation is needed, please
* Tue Dec 29 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc155
- added latest WSJT-X changes to message packing/unpacking
- option to hide hint notification char, control via Notifications tab of
  configuration settings
- patch to band scheduler functionality
- toggle skipTx1 when user's callsign is changed between standard and
  non-standard one
- option to add distance of QSO in comments of the QSO ADIF record, control
  via Reporting tab of configuration settings
- displaying output power functionality is updated to recently introduced
  Hamlib RF_POWER_METER_WATTS
- let user to get/refresh audio device list from operating system, 'Refresh'
  button is added into Audio tab of configuration settings
- update serial port list on launching JTDX configuration settings
- allow to use old CMake versions for building JTDX under Win32
- withdrawn restriction of writing UHF/VHF band change to ALL.TXT file under
  'allow TX frequency change while transmitting' option
- added 8m band
- patch: ensure mode change on rig at acceptance of the configuration settings
  changes if USB or Data/Pkt is selected in JTDX 'Radio' tab settings
- ALLCALL7.TXT update as of 20201228, big cty as of 20201223, LoTW list update
  as of 20201228
- translation updates
* Wed Dec  9 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc154
- patch to increased FT8 decoder lag issue
- avoid storing double type values in settings file to prevent any possible
  conflict with user regional settings
- translation updates
* Mon Dec  7 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc153
- patch: fill in the FT8 candidate list at valid DT range
- patch: pick up some dropped FT8 candidates at one- and two-thread decoding
- changed automatic thread number selection algorithm in FT8 decoder:
  number of logical cores/number of decoder threads
  1 / 1
  2..4 / (number of logical cores)-1
  5..8 / (number of logical cores)-2
  >8 / (number of logical cores)-3
- FT8 candidate list thinning option is implemented for usage with slow CPUs
  to let user get acceptable Lag value, "CL" spinBox is added in mainwindow
  UI with tooltip
  Default value is 100%% (no thinning). Candidate list thinning should be used
  together with "minimum" wideband FT8 decoder sensitivity setting.
  FT8 candudate list thinning being not applied to the QSO RX frequency.
  Factor 3.0 being used for thinning under frequency "Filter" option, for
  instance if CL spinBox set to 30%% then thinning factor will be 90%% (0.9)
  under frequency "Filter" option.
- implemented DT weighting and decoding pass weighting to FT8 candidate list
  thinning option, resulted in improved decoding efficiency.
  User can now select median DT value in DT spinBox of main window UI to get
  best FT8 decoder performance under candidate list thinning option, DT median
  default value is 0.0 sec.
  Median DT value of decoded signals depends on accuracy of system clock
  synchronization, in SDR setups it can also depend on RX audio delay. On
  overcrowded bands median DT value is usually close to average DT of decoded
  signals.
- FT8 decoder fast/medium/deep options are obsolete now and deleted, FT8
  decoder running now in deep mode.
- multiple changes to FT8 signal synchronization in decoder: improved FT8
  decoder efficiency on overcrowded bands
- a bit improved decoding of FT8 signals in 'use subpass' option
- simplified Hint decoder control
- FT8 mode: Hint group of decoders is always used, access to Hint button is
  blocked
- display estimated lag at decoding FT8 or FT4 wav files, estimation can have
  acceptable accuracy starting from 2nd even or 2nd odd decoded interval while
  playing pack of consecutive wav files
- patch: prevent crash with callsign index in chkfalse8.f90
- "Call higher than new calls priority callsigns" option is implemented to
  AutoSeq 4+, control is in AutoSeq tab of main window UI
- a bit faster displaytext processing
- fixed bug in CQ and ITU zone notifications
- added DX Call notification by the font color change to Other standard
  messages color
- show CQ and 73 messages marker char with CQ color for LoTW users
- prevent unneeded rig_close/open actions on Configuration settings change
  accepting
- option added to allow 160m crossband operation with South Korea, control is
  in Misc tab of main window UI
- track Monitor button state at Configuration settings changes and tuning
- forbid RRR message transmission in FT4 mode for compatibility with WSJT-X
  FT4 message protocol
- dark style correction in Configuration and widegraph UI
- better handling of large vertical size of the main UI window
- grid square for /MM /P /MM /A /M callsigns shall not be taken from
  CALL3.TXT file
- prevent saving WSPR files if "Save None" is selected
- fix 4m band default frequency at hound mode checking
- fix removing last audio .wav file on mode change
- added 70cm band FT8 frequency, frequency list reset in Configuration settings
  is needed to get it displayed in the list
- option for displaying frequency value in waterfall, "Freq" checkbox is added
  for control
- "Bars" checkbox is moved to controls widget of widegraph
- disable rig power on/off option if other than Hamlib CAT selected
- ignore UDP message client's 'TemporaryError' message for starting JTDX on Mac
  Big Sur operating system
- allow to enter 19-char directional CQ message into macro edit line in
  Configuration settings
- multiple code changes towards compatibility with Qt 5.15.1
- some changes to GCC10 support, Linux builds affected
- recovered source code Qt 5.5 compatibility to future WinXP & Vista JTDX builds
- INSTALL file is updated with disabling INDI support in hamlib
- ALLCALL7.TXT update as of 20201127, big cty as of November 12th 2020, LoTW
  list is updated
- translation updates
* Thu Aug 27 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc152
- added WSJT-X 2.2.2 FT8 protocol contest changes, version number is changed to
  2.2.0 to match it to the new WSJT-X FT8 protocol
- patch to prevent FT8 decoder freezing under Mac/Linux operating systems when
  multiple decoding cycles being used
- dark style can now be activated from General tab of configuration UI, multiple
  changes to get better appearance with dark style
- fixed AutoSeq bug for 'Wanted' in AnswerB4 configuration
- prevent FT8S/FT8SD decode with message originated from own callsign
- prevent getting incoming type 1 calls with <...> instead of user's nonstandard
  callsign(failure to associate hash with own non-standard callsign in incoming
  calls)
- FT8 frequency filter is expanded: added +-10Hz of bandwidth
- improved DT estimation for FT8 signal subtraction
- improved FT8 signals subtraction on overcrowded bands, now using GFSK waveform
  at signal subtraction
- multiple changes towards GFSK sync to FT8 signals
- patch: prevent getting out of ccfred() bounds in JT9 decoder being in JT9+65 mode
- patch: i3 type 1 decoded message starting from <...> shall not be checked for
  false decode
- patch: prevent accessing s() array out of bounds in sync8.f90
- added Radio power on/off startup option, can be controlled in 'Radio' tab of
  configuration settings via 'Rig power' checkbox, added tooltip: translation
  is needed
- patch to networking: <EQSLSDATE:8> ADIF field shall contain date
- improved eQSL checkbox control
- clear DX Call and DX Grid at band/mode change
- added keyboard shortcuts to ALT+B/C to switch to FT8/FT4 modes
- clear warnings for Qt 5.14.2 JTDX win64 builds
- minor improvement to FT8 downsampling
- handle Halt Tx -> Enable Tx sequence in FT8S decoder re-activation
- added preliminary support to Dutch language
- added Hungarian and Swedish translations, many thanks to Ali HA3LI and Roger
  SM0LTV for this contribution
- translation updates
- ALLCALL7.TXT update as of 20200820, big cty version as of 20200804, LoTW users
  list is updated as of 20200821
* Tue Jun 16 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc151
- restored band scheduler functionality
- implemented called list in QSO history with 300 second active state for callsign
- patch to AutoSeq: QSO shall be resumed upon getting R+REPORT message
- prevent starting AutoSeq4+ in wrong interval while listening(DX Call is empty),
  it caused message transmission in wrong interval
- improved AutoSeq SkipTx1 functionality
- compound callsign shall be changed to base one in QSO history upon getting
  incoming call with base callsign (compound to nonstandard callsign QSO)
- attempt to improve audio frames handling
- let Windows users to decode some FT8 intervals with drops of audio stream.
  Signals in such intervals will have wrong DT, added debug recording for
  forced decoding due to audio drops into ALL.TXT file.
- Windows OS: lost audio blocks notification and tooltip in Band Activity label
- typo error in frequency list: T10 mode frequency is changed to 24920000
- added new FT8 frequencies to 40, 30, 20 and 6m bands
- Misc tab: added option to hide decoded telemetry messages
- option to clean up wanted callsign from list at logging, enabled by default.
  'Clr' checkbox is located close to wanted callsign list, added tooltip.
- option to clean wanted grid at logging, new Clr checkbox and tooltip added
- option to hide own callsign decodes in WSPR mode
- reworked starting of decoder for partial interval decoding
- clear 12-bit hashtable if band|mode changed
- added WSJT-X 2.2.0 FT8 protocol changes
- improved sync to CQ signals: better FT8 decoder sensitivity for non-overlapped signals
- a bit improved FT8 decoding efficiency
- improved FT8 decoder sensitivity in subpass and SWL modes, also improved for
  incoming call on QSO TX/RX frequencies
- FT8 decoder shall use single thread in auto mode for dual logical core CPU
- withdrawn 'more than 3 threads' criterion for extra FT8 decoder cycles activation
- patch: FT8S messages with hashed callsign shall be parsed
- catching protocol violation: FT8 AP false decode 'mycall <...> grid'
- prevent most false decodes in DX Call searching
- some more false decode filters added
- patch to 'monitor off at startup' functionality
- intermediate JTDX builds (internal testing) shall expire in three months
- under Windows OS stdout/stderr of jtdx process shall be passed to CLI
- defined path to static LIBUSB library to let making win64 builds under JTSDK
- attempt to add QDarkStyle in JTDX, so far working under Linux only with some
  fonts with key -stylesheet :/qdarkstyle/style.qss
- translation updates
- ALLCALL7.TXT file update as of June 15th, LoTW users list is updated, big
  cty.dat as of May 20th 2020
* Wed Jun 10 2020 Walter Fey <dl8fcl@darc.de>
- fortran.diff, wsprd.diff and disable CXX warnings for Tumbleweed
* Fri May  8 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc150
- defects fixed in modulator, corrected FT8 and FT4 signal transmission
- decreased modulator start delay versus previous JTDX versions. FT4 mode
  transmit delay is set to 20ms
- improved transceiver polling functionality, transceiver polling is reworked
  for FT4 mode
- patch: transceiver poll functionality shall not trigger DT changes of FT8 TX
  signal
- attempt to improve FT4 signal transmission in scenario when poll interval is
  set greater than 1 second
- improved FT8 decoder efficiency and sensitivity
- FT8 decoder patches: minor bug fixed in candidate thinning, FT8S decodes
  shall be marked by '^' symbol and displayed with '*' symbol
- DX Call FT8 decoder searching shall trigger AF RX frequency change to the
  signal found
- AutoSeq is reworked
- patch to AutoSeq4+ in JT9+JT65 mode. Introduced tx_mode change event into AutoSeq.
- IARU regions implemented: user now can have common for all regions and own
  region frequencies in the frequency list
- fixed nearest default frequency search for multiple default frequencies in
  the frequency list
- patch: restore default frequency on startup if frequency that is not in the
  list was saved at last exit from JTDX
- patch: at program launching frequency shall be set to nearest default frequency
- frequency list can be saved to file and loaded from file. There is no 'RESET'
  button in Frequency tab anymore, please use right mouse's button click on the
  frequency list to get to controls
- 4m band frequency list is updated
- removed JA and EU dependencies from forcing 160m crossband: now such
  crossband operation with Japan is fully optional
- patch to WSPR decoder crash in scenario where message with empty grid decoded
- unified system date/time implemented
- code reworked to unified MessageBox usage
- patch to DXpedition special message parsing for 11-char callsign
- added DXpedition special message parsing in FT4 decoder
- minor bug fixed in JT65 decoder
- Band Activity window label shall not be part of 'Hide menus' functionality
- decoder's lag shall be displayed in Band Activity window label: lag is
  calculated relatively to beginning of next interval. Negative values mean
  spare time can be used for deeper decoding, positive values is decoder's lag
  into TX or next interval. Added detailed decoder's lag description in tooltip
  to Decoded Text label.
- added counter of last interval decoded messages into Band Activity window label
- 'wanted country' line edit shall allow to enter asterisk symbol with prefix
- 'wanted country' and 'country filter' prefix search shall include asterisk
  and shall be done with prefix at uppercase
- added verical bars for RX and TX frequencies into waterfall as new option
- common band 22-bit hash table shall be cleaned at band|mode change
- more filters added to catch false FT8 and FT4 decodes
- improved prefix-to-grid mapping(false decode detection functionality)
- defect fixed in filtering false 'CQ  callsign/R' messages
- QSO_DATE_OFF and TIME_OFF ADIF parameters shall be passed over network
- Escape keyboard button shall also halt Tx if widegraph window is active
- attempt to fit timestamp into waterfall at NAvg=3 on all operating systems
- added 'debug to file' option on build, recording into JTDX_debug.txt file
- added Portuguese Brazilian, Danish and Catalan languages and translation
- removed date/time format string translations in logqso UI
- translation updates
- changes to Hound button background color: yellow in common FT8 bands, green
  color if out of common FT8 bands
- AutoTx button alert color is changed from yellow to soft red one
- minor changes to keyboard shorcuts description
- using big CTY file now, updated ALLCALL7.TXT, LoTW users list, big CTY is
  updated to version as of April 18th
* Thu Apr  2 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc149
- implemented multilanguage support, JTDX shall restart automatically at language change
- added translation to Estonian, Russian, Chinese, Japanese, Croatian, Spanish, Portuguese, Italian, Polish and French languages. Many thanks to JTDX users who contributed translation to their native language.
- added 'new CQ' and 'new ITU' zone notifications, priorities are in the same order as listed in Notifications tab of configuration settings
- improved sensitivity of FT8 decoder
- FT8 decoder: increased SNR threshold up to -20.5 dB for false decode checking
- callsign prefixes mapped to grid in FT8 decoder, being used to check for false CQ decodes
- FT8 AP mask decoder CQ messages with wrong grid square shall be checked for false decodes with -18.5 dB SNR threshold
- FT4 AP mask decoder CQ messages with wrong grid square shall be checked for false decodes with -15.0 dB SNR threshold
- reworked FT8 candidate list thinning: reduced decoding time of FT8 interval and number of false decodes
- subpass shall always be used in FT8 decoder on QSO RX frequency and when needed on QSO TX frequency
- patched minor defects in callsign checking against false FT8 decodes
- patch to memory corruption in WSPR decoder
- allow to halt Tx via 'Escape' keyboard button
- fixed waterwall palette designer and made new palete Default16
- patch to band scheduler functionality
- patch to keyboard shortcut functionality of Tune button
- 'DE' is allowed as CQ direction
- FT8 decoder DX Call searching functionality: callsigns ending with '/R' shall be checked against ALLCALL7 list
- 'Halt Tx: reply to other' shall not be triggered in AutoSeq if message addressed to user decoded before message addressed to other operator (scenario where message is changed at transmission and both messages decoded)
- added WSPR band guard for 160..4m bands, shall be displayed in widegraph, any other mode TX is prohibited in WSPR bands
- updated Linux man pages
- split win32/win64 installation path as workaround to wrong USB audio device configuration in Windows registry, use RC number as installation folder. Default installation path is optional, user can change/edit it at JTDX installation.
- country file updated to version CTY-3005, LoTW users list and ALLCALL7.TXT are updated
* Thu Feb 20 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc148
- reordered launching of threads in FT8 decoder
- minor changes to Spt/Menu controls view, reversed broken Pwr slider appearance
- 'fusion' is set as default JTDX style, '-style=windows' key in JTDX launching
  shortcut will switch 'fusion' style off
- crossband 160m band operation with Japan is moved to option for all scenarios
  but EU-JA QSO, by default crossband is enabled, can be switched off in Misc
  tab of main window UI
- patch to possible marker misalignment in QSO RX frequency messages window
  triggered at double click on message
- messages like '73' shall not be treated as 'reply to other' while
  correspondent using multislot transmission
- prevent calling on Fox frequency when user resuming TX after three
  unsuccessful TX attempts
- added optional broadcast of logged QSO ADIF message to secondary UDP server,
  the same message format as in WSJT-X being used, controls are in 'Reporting'
  tab of configuration settings, same message format as in WSJT-X is used
- 'Logged ADIF' UDP message addressed to primary UDP server now is optional,
  can be activated in 'Reporting' tab of configuration settings
- main frequencies introduced, marked in frequency list by asterisk. At mode
  change JTDX will be selecting main frequency rather than Fox frequency.
  Some frequently used DXpedition frequencies added as default values in the
  frequency list. Main mode&band frequencies can be deleted by user, 'reset
  frequency list' will recover default frequencies
- six-pass SWL option is withdrawn from FT8 decoder
- implemented up to 3 cycles of FT8 decoding (each cycle has three decoding
  passes, six-pass SWL mode was two cycle decoding), one cycle is set by
  default, two or three cycles can be activated independently for operation and
  SWL modes.
  Withdrawn multicycle FT8 decoding dependency on number of running JTDX
  instances. Still there shall be more than 3 threads used in FT8 decoder to
  get multicyle decoding active in SWL mode.
- Hint button shall be switched on in FT8 mode by default(first launch of JTDX
  or if .ini file is deleted)
- automatic FT8 decoder thread selection shall spare one thread to other tasks
  if CPU has more than 2 logical cores. If user sure in flawless CPU & software
  functionality he|she can bring back decoding time selecting manually number
  of FT8 decoder threads equal to number of CPU logical cores.
  - FT8 decoder AP masks related code cleanup
- main window UI: CAT recovery button is moved up close to frequency label,
  minor changes to top/right side buttons allocation
- thinning FT8 candidate list based on the sync pattern quality: 3..15%%
  decrease of decoding time of FT8 interval
- upon accepting configuration settings JTDX shall retain current VFO frequency
  if it matches to a frequency in the list, else shall set main mode&band frequency
- patch for counters when doubleclicked on call which is not in history (no
  CQ or 73 like messages received from this callsign), first counter did
  not work in such scenario
- ALLCALL7.TXT is now being used for filtering false FT8 decodes with support
  of 7-char Australian callsigns, ALLCALL.TXT is not used anymore
- filtering false decodes: faster callsign search in the ALLCALL7 based list
  via block data access
- added checking for false FT4 decodes starting from "TU; "
- added SNR and DT criteria for checking FT8 false decodes containing " R "
- one more attempt to eliminate 'CQ DE AA00' false FT8 decode, it was likely
  coming from OSD decoder with AP mask in presence of strong signal on the band
- LoTW users list is updated, cty.dat file is updated to version CTY-3004
- ALLCALL7.TXT is updated to 111851 callsigns
* Sun Jan 26 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc147
- major defect in FT8 decoder fixed for 64bit builds
- JTDX-win64 build is made under Qt 5.14.0, approximately 1.6 times faster in
  decoding FT8 signals (tested with 4 threads) on overcrowded band versus
  JTDX-win32 built under Qt 5.5
- reworked meter stuff, now should be also bulletproof around enabling meter
  for rigs where it is not supported. RF output power indication should work
  with Icoms: ic7000, ic7100, ic7200, ic7300, ic7410, ic756pro3, ic7600,
  ic7610, ic7700, ic7800, ic785x with new introduced RFPOWER_METER level function.
- attempt to get S-meter indication for Yaesu ft100,ft450,ft600,ft736,ft757gx,
  ft950,ft1000mp,ft1200,ft2000,ft5000,ft9000
- attempt to enable RF output power indication for new Yaesu radios using newcat protocol
- reworked S-meter indication for any new Yaesu radio where newcat protocol being used
- FT8 FT4 decoders shall clear in current interval audio frames received prior
  to the band change
- attempt to prevent "CQ DE AA00" false message created by FT8 decoder
- allow to set AF RX frequency below 200 Hz
- status bar: date format is changed to DD.MM.YYYY
- LoTW users file is updated, cty.dat is updated to CTY-3001 version
* Tue Jan  7 2020 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc146
- allow transmission of DXpedition special message from Tx2
- cursor position shall be stored/restored while operator's callsign&grid
  being edited in configuration settings
- empty message shall be treated as false decode in FT4 decoder
- some Decode control related code cleanup
- workaround to modulator start failure(no TX audio issue)
- patch to 'Decode button hung up' issue in FT4 and FT8 modes
- JTDX shall not attempt to start decoder if it is working
- patch to broken decoding of FT8 signals in scenario where both user's and
  correspondent's callsigns are nonstandard ones
- compound-to-compound callsign QSO Tx message generation is supported now.
  Compound-to-compound callsign QSO is possible between JTDX 2.1.0-rc146 and
  MSHV v2.32 users, Tx message generation could be changed in WSJT-X to
  provide support for such QSO.
- two more chars added in displaytext and decoders to fit messages like
  "CC2/CC1CCC BB2/BB1BBB R-15" in Band Activity and RX frequency text windows
- FT8 decoder shall process signals with "CQ ??? ???" AP mask if there is
  nonstandard callsign in DxCall window
- improved DxCall searching if there is nonstandard callsign in DxCall window
- number of FT8 decoder threads shall not exceed number of logical cores
- FT8: added option to SWL mode to utilize 3 more decoding passes.
- user can add second callsign from a decoded message into wanted callsign list
  via (CTRL+ALT+double-click) on the message if the list has less than 20
  callsigns and this callsign being not located in DxCall window.
  Wanted callsign list can be cleared via CTRL+ALT+A keyboard shortcut.
- reset QSO history counters for new call when DxCall is changed with double click
- at double click on decoded message cursor position shall be set prior to
  emitting of the selectCallsign(alt,ctrl) signal
- added option to copy callsign to clipboard at double-click on the decoded
  message or at autoselection. By default this option is enabled, can be
  switched off in Misc tab of mainwindow UI.
- cty.dat file is updated to version CTY-2918, LoTW users file is updated
* Sun Dec 15 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc145
- added Filter functionality to FT4 mode
- option to hide contest messages is expanded to FT4 mode
- added 4th decoding pass to WSPR decoder, improved sensitivity
- some cleanup changes to FT8 AP mask functionality
- base callsigns shall be used in FT8 AP masks for standard messages in Hound mode
- new exceptions added: ???/ND /KT /AG /AE shall not be treated as callsign's
  prefixes
- attempt to make Fox/Hound compound/compound callsign QSO possible in AutoSeq:
  Tx3 message is changed to "<FoxCompoundCall> MyBaseCall RREPORT" in Hound
  mode if both callsigns are compound
- DX Call signal searching with FT8 AP masks is implemented for CQ/73/RR73
  messages raising FT8 decoder sensitivity up to 4dB: QSO RX frequency by
  default, optionally wideband DX Call search.
  DX Call signal searching being activated if there is DX callsing in DX Call
  window, Enable Tx button is switched off and DX Call is not the same as last
  logged callsign variable value.
  New mainwindow UI controls: Decode->FT8 decoding->Wideband DX Call search
- DX Call signal searching being supported for nonstandard base callsign and
  compound callsign
- DX Call signal searching being supported in Hound mode
- 'CQ <...>' message shall be treated as false decode
- some code changes based on the Valgrind checking results
- wanted grid functionality is implemented, where 4-char grid being supported
  only, user can fill in comma separated list of grids in the 'wanted' area of
  main window UI, tooltip added there.
  'Wanted grid' in autoselection has the same priority as 'wanted prefix'.
- special DXpedition messages shall be underlined with dashed line. To resolve
  conflict with B4 underlined with straight line B4 special message shall be
  underlined with the waved line.
  To avoid any possible confusion starting from rc145 we recommend to use
  'strike B4' option instead of the 'underline B4' one.
- changed line length for B4 notification (striked|underlined)
- QSO history shall forget interrupted/unfinished QSO in 5 minutes since first
  message transmission
- 'wanted' CQ/RR73/73 messages shall have lower priority in autoselection versus
  any incoming call to user
- "Highlight worked ones" option shall be disabled by default (first run of
  JTDX with new ini file)
- LoTW users file is updated
- hamlib_rig.h.diff removed. Fixed upstream.
* Thu Dec  5 2019 Walter Fey <dl8fcl@darc.de>
- hamlib_rig.h.diff to fix latest changes in hamlib
* Mon Dec  2 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc144
* Thu Nov 21 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc143
* Thu Nov 14 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc142
* Tue Nov  5 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc141
* Sun Oct  6 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.1.0-rc140
* Sat Jul 20 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.0.2-rc139
* Wed Jul 10 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.0.1-rc138
* Fri May 24 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.0.1-rc137_1
* Sun Apr 14 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.0.1-rc135
* Tue Apr  9 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.0.1-rc134
* Fri Mar 15 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.0.1-rc133
* Thu Mar  7 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.0.1-rc132
* Fri Mar  1 2019 Walter Fey <dl8fcl@darc.de>
- update to test version 2.0.1-rc131
* Tue Feb 19 2019 dl8fcl@darc.de
- update to test version 2.0.1-rc130
* Sun Feb 10 2019 dl8fcl@darc.de
- update to test version 2.0.1-rc129
* Sun Jan 27 2019 dl8fcl@darc.de
- update to test version 2.0.1-rc127
* Tue Jan 22 2019 dl8fcl@darc.de
- update to test version 2.0.1-rc126
* Sun Jan 13 2019 dl8fcl@darc.de
- update to test version 2.0.1-rc124
* Tue Jan  8 2019 dl8fcl@darc.de
- update to test version 2.0.1-rc123
* Wed Jan  2 2019 dl8fcl@darc.de
- update to test version 2.0.1-rc122
* Sun Dec 30 2018 dl8fcl@darc.de
- patch to not build/install redundant binaries with hamlib
  found at fedorainfracloud.org from Richard Shaw(hobbes1069)
* Tue Dec 25 2018 dl8fcl@darc.de
- update to test version 2.0.1-rc117
* Wed Dec 19 2018 dl8fcl@darc.de
- update to test version 2.0.1-rc115
  this rc has basic FT8v2 decoding function
* Sun Dec  9 2018 dl8fcl@darc.de
- update to test version 18.1.106
* Thu Dec  6 2018 dl8fcl@darc.de
- update to test version 18.1.105
* Sat Nov 24 2018 dl8fcl@darc.de
- update to test version 18.1.102
* Sun Nov  4 2018 dl8fcl@darc.de
- update to test version 18.1.100
- a tag added, to show on pskreporter who is using this version
* Sun Oct 28 2018 dl8fcl@darc.de
- update to test version 18.1.99
* Wed Oct 17 2018 dl8fcl@darc.de
-  update to test version 18.1.95
* Thu Sep 27 2018 dl8fcl@darc.de
- update to test version 18.1.0.92
* Tue Aug  7 2018 dl8fcl@darc.de
- first try
